SpeakerUserModel class

Constructors

SpeakerUserModel({required String userID, required String username, required bool isMicMuted, required bool isVideoON, required bool isFrontCam, String? sessionKey, bool isNeedTwice = false})
SpeakerUserModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isFrontCam bool
getter/setter pair
isMicMuted bool
getter/setter pair
isNeedTwice bool
getter/setter pair
isVideoON bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionKey String?
getter/setter pair
userID String
final
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited